#ifndef __LT_FDC2214_IIC_H
#define __LT_FDC2214_IIC_H
#include <stdint.h>
#include "gpio.h"

/********************************************移植修订点*****************************************************/
/* 定义FDC2214连接的GPIO端口 软件IIC */

extern SoftI2C_HandleTypeDef hi2c1;
extern SoftI2C_HandleTypeDef hi2c2;

/********************************************移植修订点结束*****************************************************/

void SoftI2C_Init(SoftI2C_HandleTypeDef* hi2c);
void delay_us(uint32_t us);
void FDC2214_IIC_Start(SoftI2C_HandleTypeDef* hi2c);
void FDC2214_IIC_Stop(SoftI2C_HandleTypeDef* hi2c);
uint8_t FDC2214_IIC_Wait_Ack(SoftI2C_HandleTypeDef* hi2c);
void FDC2214_IIC_Ack(SoftI2C_HandleTypeDef* hi2c);
void FDC2214_IIC_NAck(SoftI2C_HandleTypeDef* hi2c);
void FDC2214_IIC_Send_Byte(SoftI2C_HandleTypeDef* hi2c, uint8_t dat);
uint8_t FDC2214_IIC_Read_Byte(SoftI2C_HandleTypeDef* hi2c, uint8_t ack);

#endif
